@@ -150,6 +150,9 @@ class SwerveDrivetrain(Subsystem):
         self.chassis_speeds: ChassisSpeeds | None = None
         self._omega: radians_per_second = 0
 
+        self.node_translations: tuple[Translation2d] | None = None
+        self.swerve_positions: tuple[SwerveModulePosition] | None = None
+
     def init(self):
         """
         Initialize the swerve drivetrain, kinematics, odometry, and gyro.
@@ -160,15 +163,21 @@ class SwerveDrivetrain(Subsystem):
         self.n_10.init()
         self.n_11.init()
         self.gyro.init()
+
         logger.info("initializing odometry", "[swerve_drivetrain]")
-        self.kinematics = SwerveDrive4Kinematics(
+
+        self.node_translations = (
             Translation2d(-.5 * self.track_width, -.5 * self.track_width),
             Translation2d(-.5 * self.track_width, .5 * self.track_width),
             Translation2d(.5 * self.track_width, -.5 * self.track_width),
             Translation2d(.5 * self.track_width, .5 * self.track_width)
         )
 
-        swerve_positions = (
+        self.kinematics = SwerveDrive4Kinematics(
+            *self.node_translations
+        )
+
+        self.swerve_positions = (
             SwerveModulePosition(
                 distance=((self.track_width * .5)**2 + (.5 * self.track_width)**2)**.5,
                 angle=Rotation2d(math.atan2(-.5 * self.track_width, -.5 * self.track_width))
@@ -190,13 +199,13 @@ class SwerveDrivetrain(Subsystem):
         self.odometry = SwerveDrive4Odometry(
             self.kinematics,
             Rotation2d(self.gyro.get_robot_heading()),
-            swerve_positions,
+            self.swerve_positions,
             self.start_pose
         )
         self.odometry_estimator = SwerveDrive4PoseEstimator(
             self.kinematics,
             Rotation2d(self.gyro.get_robot_heading()),
-            swerve_positions,
+            self.swerve_positions,
             self.start_pose
         )
 
